# Generate data
import random

# this generates a list that has every date for July and August 2022
dates = [f'2022/07/{i+1:02}' for i in range(31)]
dates.extend(f'2022/08/{i+1:02}' for i in range(31))

# this generates random availabilities for each site
# site one has a 50% chance of availability each day
# site two has a 70% chance of availability each day
# site three has an 80% chance of availability each day
site1 = [('Available' if random.random() < 0.5 else 'Unavailable') for date in dates]
site2 = [('Available' if random.random() < 0.7 else 'Unavailable') for date in dates]
site3 = [('Available' if random.random() < 0.8 else 'Unavailable') for date in dates]

# printing all this so you can see what it looks like
print(dates)
print(site1)
print(site2)
print(site3)

# printing the first 10 zipped tuples so you can see what this looks like
for tup in zip(dates, site1, site2, site3[:10]):
    print(*tup)

# solution

# we are going to keep track of every open window. An open window is a list of dates where all three sites
# are available
open_windows = []
# the current window is what we use to accumualte a list of dates where all three sites are available
current_window = []

# loop through the zipped tuples (date, site1availability, site2availability, site3availability)
for date, s1, s2, s3 in zip(dates, site1, site2, site3):
    # if all three sites are available...
    if s1 == 'Available' and s1 == s2 and s1 == s3:
        # ... add this date to the current window
        current_window.append(date)
    else:
        # ... otherwise, add the current window to our list of open windows
        open_windows.append(current_window)
        # and reset the current window to be empty
        current_window = []
# when we exit the loop, we have a current window, so add it to the list of windows
open_windows.append(current_window)

# Find the longest window out of all of the open windows
# Note that open_windows is a list of lists! We need to loop through it and find the longest list
max_window = None
for window in open_windows:
    if max_window is None or len(window) > len(max_window):
        max_window = window

# Print the dates in the maximum open window
print(max_window)
